public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "Wang, Sunny (HPS SW)" <sunnywang@hpe.com>
To: Liming Gao <liming.gao@intel.com>,
	"edk2-devel@lists.01.org" <edk2-devel@lists.01.org>
Subject: Re: [PATCH v2] MdeModulePkg UefiBootManagerLib: Rename BootMenuApp to BootManagerMenu
Date: Thu, 1 Sep 2016 07:23:04 +0000	[thread overview]
Message-ID: <TU4PR84MB030480CA78934CB71FC34408A8E20@TU4PR84MB0304.NAMPRD84.PROD.OUTLOOK.COM> (raw)
In-Reply-To: <1472709886-58924-1-git-send-email-liming.gao@intel.com>

Looks good to me.
Reviewed-by: Sunny Wang <sunnywang@hpe.com>

Regards,
Sunny Wang

-----Original Message-----
From: edk2-devel [mailto:edk2-devel-bounces@lists.01.org] On Behalf Of Liming Gao
Sent: Thursday, September 01, 2016 2:05 PM
To: edk2-devel@lists.01.org
Subject: [edk2] [PATCH v2] MdeModulePkg UefiBootManagerLib: Rename BootMenuApp to BootManagerMenu

Rename local function name BootMenuApp to BootManagerMenu to align to other public function name.

In V2, use "BootManagerMenu" instead of "BootMenuApp".

Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Liming Gao <liming.gao@intel.com>
Reviewed-by: Ruiyu Ni <ruiyu.ni@intel.com>
---
 MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c b/MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c
index ecd0ae3..fe09a04 100644
--- a/MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c
+++ b/MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c
@@ -1530,15 +1530,15 @@ EfiBootManagerGetLoadOptionBuffer (  }
 
 /**
-  Check if it's a Device Path pointing to BootMenuApp.
+  Check if it's a Device Path pointing to BootManagerMenu.
 
   @param  DevicePath     Input device path.
 
-  @retval TRUE   The device path is BootMenuApp File Device Path.
-  @retval FALSE  The device path is NOT BootMenuApp File Device Path.
+  @retval TRUE   The device path is BootManagerMenu File Device Path.
+  @retval FALSE  The device path is NOT BootManagerMenu File Device Path.
 **/
 BOOLEAN
-BmIsBootMenuAppFilePath (
+BmIsBootManagerMenuFilePath (
   EFI_DEVICE_PATH_PROTOCOL     *DevicePath
 )
 {
@@ -1645,7 +1645,7 @@ EfiBootManagerBoot (
   // 3. Signal the EVT_SIGNAL_READY_TO_BOOT event when we are about to load and execute
   //    the boot option.
   //
-  if (BmIsBootMenuAppFilePath (BootOption->FilePath)) {
+  if (BmIsBootManagerMenuFilePath (BootOption->FilePath)) {
     DEBUG ((EFI_D_INFO, "[Bds] Booting Boot Manager Menu.\n"));
     BmStopHotkeyService (NULL, NULL);
   } else {
@@ -2080,10 +2080,10 @@ BmEnumerateBootOptions (
     ASSERT (BootOptions != NULL);
 
     //
     // If LoadFile includes BootMenuApp, its boot attribue will be set to APP and HIDDEN.
     //
     BootAttributes = LOAD_OPTION_ACTIVE;
-    if (BmIsBootMenuAppFilePath (DevicePathFromHandle (Handles[Index]))) {
+    if (BmIsBootManagerMenuFilePath (DevicePathFromHandle 
+ (Handles[Index]))) {
       BootAttributes = LOAD_OPTION_CATEGORY_APP | LOAD_OPTION_ACTIVE | LOAD_OPTION_HIDDEN;
     }
 
@@ -2215,7 +2215,7 @@ BmRegisterBootManagerMenu (
   DevicePath = NULL;
   Description = NULL;
   //
   // Try to find BootMenuApp from LoadFile protocol
   //
   gBS->LocateHandleBuffer (
          ByProtocol,
@@ -2225,7 +2225,7 @@ BmRegisterBootManagerMenu (
          &Handles
          );
   for (Index = 0; Index < HandleCount; Index++) {
-    if (BmIsBootMenuAppFilePath (DevicePathFromHandle (Handles[Index]))) {
+    if (BmIsBootManagerMenuFilePath (DevicePathFromHandle 
+ (Handles[Index]))) {
       DevicePath  = DuplicateDevicePath (DevicePathFromHandle (Handles[Index]));
       Description = BmGetBootDescription (Handles[Index]);
       break;
@@ -2334,7 +2334,7 @@ EfiBootManagerGetBootManagerMenu (
   BootOptions = EfiBootManagerGetLoadOptions (&BootOptionCount, LoadOptionTypeBoot);
 
   for (Index = 0; Index < BootOptionCount; Index++) {
-    if (BmIsBootMenuAppFilePath (BootOptions[Index].FilePath)) {
+    if (BmIsBootManagerMenuFilePath (BootOptions[Index].FilePath)) {
         Status = EfiBootManagerInitializeLoadOption (
                    BootOption,
                    BootOptions[Index].OptionNumber,
@@ -2080,10 +2080,10 @@ BmEnumerateBootOptions (
 
     //
-    // If LoadFile includes BootMenuApp, its boot attribue will be set to APP and HIDDEN.
+    // If LoadFile includes BootManagerMenu, its boot attribue will be set to APP and HIDDEN.
     //
     BootAttributes = LOAD_OPTION_ACTIVE;
@@ -2215,7 +2215,7 @@ BmRegisterBootManagerMenu (
   Description = NULL;
   //
-  // Try to find BootMenuApp from LoadFile protocol
+  // Try to find BootManagerMenu from LoadFile protocol
   //
   gBS->LocateHandleBuffer (
--
2.8.0.windows.1

_______________________________________________
edk2-devel mailing list
edk2-devel@lists.01.org
https://lists.01.org/mailman/listinfo/edk2-devel


      reply	other threads:[~2016-09-01  7:23 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-09-01  6:04 [PATCH v2] MdeModulePkg UefiBootManagerLib: Rename BootMenuApp to BootManagerMenu Liming Gao
2016-09-01  7:23 ` Wang, Sunny (HPS SW) [this message]

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=TU4PR84MB030480CA78934CB71FC34408A8E20@TU4PR84MB0304.NAMPRD84.PROD.OUTLOOK.COM \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox